==> ci-auto-update-phpboost-6.0.3.zip: phpboost_ynh/README_fr.md <==
<!--
Nota bene : ce README est automatiquement généré par <https://github.com/YunoHost/apps/tree/master/tools/readme_generator>
Il NE doit PAS être modifié à la main.
-->

# PHPBoost pour YunoHost

[![Niveau d’intégration](https://dash.yunohost.org/integration/phpboost.svg)](https://dash.yunohost.org/appci/app/phpboost) ![Statut du fonctionnement](https://ci-apps.yunohost.org/ci/badges/phpboost.status.svg) ![Statut de maintenance](https://ci-apps.yunohost.org/ci/badges/phpboost.maintain.svg)

[![Installer PHPBoost avec YunoHost](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=phpboost)

*[Lire le README dans d'autres langues.](./ALL_README.md)*

> *Ce package vous permet d’installer PHPBoost rapidement et simplement sur un serveur YunoHost.*  
> *Si vous n’avez pas YunoHost, consultez [ce guide](https://yunohost.org/install) pour savoir comment l’installer et en profiter.*

## Vue d’ensemble

PHPBoost allows everyone to create his own website without any particular knowledge required in webmastering.

**Version incluse :** 6.0.3~ynh1

**Démo :** <https://demo.phpboost.com/>

## Captures d’écran

![Capture d’écran de PHPBoost](./doc/screenshots/screenshot.png)

## Documentations et ressources

- Site officiel de l’app : <https://www.phpboost.com/>
- Documentation officielle de l’admin : <https://www.phpboost.com/wiki/wiki.php>
- Dépôt de code officiel de l’app : <https://github.com/PHPBoost/PHPBoost>
- YunoHost Store : <https://apps.yunohost.org/app/phpboost>
- Signaler un bug : <https://github.com/YunoHost-Apps/phpboost_ynh/issues>

## Informations pour les développeurs

Merci de faire vos pull request sur la [branche `testing`](https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing).

Pour essayer la branche `testing`, procédez comme suit :

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
ou
sudo yunohost app upgrade phpboost -u https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
```

**Plus d’infos sur le packaging d’applications :** <https://yunohost.org/packaging_apps>

==> ci-auto-update-phpboost-6.0.4.zip: phpboost_ynh/README_fr.md <==
<!--
Nota bene : ce README est automatiquement généré par <https://github.com/YunoHost/apps/tree/master/tools/readme_generator>
Il NE doit PAS être modifié à la main.
-->

# PHPBoost pour YunoHost

[![Niveau d’intégration](https://dash.yunohost.org/integration/phpboost.svg)](https://ci-apps.yunohost.org/ci/apps/phpboost/) ![Statut du fonctionnement](https://ci-apps.yunohost.org/ci/badges/phpboost.status.svg) ![Statut de maintenance](https://ci-apps.yunohost.org/ci/badges/phpboost.maintain.svg)

[![Installer PHPBoost avec YunoHost](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=phpboost)

*[Lire le README dans d'autres langues.](./ALL_README.md)*

> *Ce package vous permet d’installer PHPBoost rapidement et simplement sur un serveur YunoHost.*  
> *Si vous n’avez pas YunoHost, consultez [ce guide](https://yunohost.org/install) pour savoir comment l’installer et en profiter.*

## Vue d’ensemble

PHPBoost allows everyone to create his own website without any particular knowledge required in webmastering.

**Version incluse :** phpboost-6.0.4~ynh1

**Démo :** <https://demo.phpboost.com/>

## Captures d’écran

![Capture d’écran de PHPBoost](./doc/screenshots/screenshot.png)

## Documentations et ressources

- Site officiel de l’app : <https://www.phpboost.com/>
- Documentation officielle de l’admin : <https://www.phpboost.com/wiki/wiki.php>
- Dépôt de code officiel de l’app : <https://github.com/PHPBoost/PHPBoost>
- YunoHost Store : <https://apps.yunohost.org/app/phpboost>
- Signaler un bug : <https://github.com/YunoHost-Apps/phpboost_ynh/issues>

## Informations pour les développeurs

Merci de faire vos pull request sur la [branche `testing`](https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing).

Pour essayer la branche `testing`, procédez comme suit :

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
ou
sudo yunohost app upgrade phpboost -u https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
```

**Plus d’infos sur le packaging d’applications :** <https://yunohost.org/packaging_apps>
